# Buffy documentation and issue Tracker

Buffy is a **versioning and caching kinda-proxy for decoupling external HTTP resources** made by the German Center for Diabetes Research Datamanagement Team   

This repository contains the documentation and serves as a public issue tracker for Buffy.  

You can visit the full documentation at [https://dzd-ev.github.io/buffy-docs.github.io/](https://dzd-ev.github.io/buffy-docs.github.io/)  
  
The source code lives in our GitLab instance at [https://git.connect.dzd-ev.de/dzdpythonmodules/buffy](https://git.connect.dzd-ev.de/dzdpythonmodules/buffy)